<?php
// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

//Setting default options when plugin is activated and writing the result JS file
function livicons_evolution_plugin_activation() {
	// check whether the WordPress file system API can be used
	if( 'direct' === get_filesystem_method() ) {
		$creds = request_filesystem_credentials( content_url() . '/', '', false, false, array() );
		if ( ! WP_Filesystem( $creds ) ) {
			return false;
		}
	} else {
		// don't have direct write access.
		wp_die( 
			sprintf(
				'<strong>' .
				esc_html__( 'LivIcons Evolution plugin', 'livicons-evo' ) . 
				'</strong> ' .
				esc_html__( "requires the direct file system access on your server, and has been deactivated! Unfortunately, the plugin cannot be used. Please contact the plugin's author.", "livicons-evo") . 
				'<br><br>' .
				esc_html__( 'Back to', 'livicons-evo' ) .
				' <a href="%1$s">' .
				esc_html__( 'WordPress Dashboard', 'livicons-evo' ) .
				'</a>.',
				esc_url( admin_url() )
			)
		);
	}

	//saving new installed version number
	update_option( 'livicons_evolution_version', LIVICONS_EVOLUTION_VERSION );

	//getting factory defaults
	$defaults = livicons_evolution_factory_defaults();
	
	$saved_general = get_option( 'livicons_evolution_general_options' );
	if ( $saved_general === false ) {
		$saved_general = array();
	}
	//to prevent overwriting users values
	$result_general = array_merge( $defaults['general'], $saved_general );

	$saved_visual = get_option( 'livicons_evolution_visualization_options' );
	if ( $saved_visual === false ) {
		$saved_visual = array();
	}
	$result_visual = array_merge( $defaults['visual'], $saved_visual );

	$saved_anim = get_option( 'livicons_evolution_animation_options' );
	if ( $saved_anim === false ) {
		$saved_anim = array();
	}
	$result_anim = array_merge( $defaults['anim'], $saved_anim );

	$saved_activation = get_option( 'livicons_evolution_activation' );
	if ( $saved_activation === false ) {
		$saved_activation = array();
	}
	$result_activation = array_merge( $defaults['activation'], $saved_activation );
	
	//if restoring of factory defaults is checked
	if( ( $result_general['check_default_options_db'] === 'true' ) ) {
		delete_option( 'livicons_evolution_general_options' );
		delete_option( 'livicons_evolution_visualization_options' );
		delete_option( 'livicons_evolution_animation_options' );

		update_option( 'livicons_evolution_general_options', $defaults['general'] );
		update_option( 'livicons_evolution_visualization_options', $defaults['visual'] );
		update_option( 'livicons_evolution_animation_options', $defaults['anim'] );
		
		$tmp = array_merge( $defaults['general'], $defaults['visual'], $defaults['anim'] );
		livicons_evolution_save_result_file( $tmp );
	} else {
		update_option( 'livicons_evolution_general_options', $result_general );
		update_option( 'livicons_evolution_visualization_options', $result_visual );
		update_option( 'livicons_evolution_animation_options', $result_anim );
		update_option( 'livicons_evolution_activation', $result_activation );
		
		$tmp = array_merge( $result_general, $result_visual, $result_anim );
		livicons_evolution_save_result_file( $tmp );
	}
}
register_activation_hook( LIVICONS_EVOLUTION_FILE, 'livicons_evolution_plugin_activation' );

// Checks the version number and activate if necessary
function livicons_evolution_check_version() {
	$cur_version = get_option( 'livicons_evolution_version' );
	//reset activation once, for using new update plugin function (since 2.7.379)
	if ( version_compare( $cur_version, '2.7', '<' ) ) {
		$activation_data = array(
			'purchase_code' => '',
			'is_activated' => 'false',
		);
		update_option( 'livicons_evolution_activation', $activation_data );
	}
	// It's absolutely necessary to use "!=" instead of "!=="
	if ( version_compare( LIVICONS_EVOLUTION_VERSION, $cur_version, '!=' ) ) {
		livicons_evolution_plugin_activation();
	}
}
add_action( 'admin_init', 'livicons_evolution_check_version' );