<?php
// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// registering styles and scripts
function livicons_evolution_register_main_assets() {
	wp_register_style(
		'livicons-evolution-styles',
		LIVICONS_EVOLUTION_URL . 'assets/css/LivIconsEvo.WP.css',
		false,
		LIVICONS_EVOLUTION_VERSION
	);
	wp_register_script(
		'livicons-evolution-tools',
		LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.WP.tools.js',
		false,
		LIVICONS_EVOLUTION_VERSION,
		true
	);
	wp_register_script(
		'livicons-evolution-defaults',
		LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.WP.defaults.js',
		array( 'jquery' ),
		get_option( 'livicons_evolution_dynamic_string', '' ),
		true
	);
	wp_register_script(
		'livicons-evolution-core',
		LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.WP.min.js',
		array( 'jquery', 'livicons-evolution-tools', 'livicons-evolution-defaults' ),
		LIVICONS_EVOLUTION_VERSION,
		true
	);
	wp_register_script(
		'livicons-evolution-gutenberg-js',
		LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.gutenberg.js',
		array(
			'livicons-evolution-core',
			'wp-element',
			'wp-rich-text',
			'wp-format-library',
			'wp-i18n',
			'wp-editor',
			'wp-compose',
			'wp-components'
		),
		LIVICONS_EVOLUTION_VERSION,
		true
	);
}
add_action( 'init', 'livicons_evolution_register_main_assets' );

// enqueue styles and scripts for site's dashboard, front-end and check for shortcode is allowed 
function livicons_evolution_general_assets() {
	//Allow or not LivIcons Evo in widgets, comments and excerpts
	$options = get_option('livicons_evolution_general_options');
	if( isset( $options['in_widgets'] ) && $options['in_widgets'] === 'true' ) {
		add_filter( 'widget_text', 'do_shortcode' ); 
	}
	if( isset( $options['in_comments'] ) && $options['in_comments'] === 'true' ) {	
		add_filter( 'comment_text', 'do_shortcode' ); 
	}
	if( isset( $options['in_excerpts'] ) && $options['in_excerpts'] === 'true' ) {
		add_filter( 'the_excerpt', 'do_shortcode' ); 
	}

	global $pagenow;

	$include_on_pages = array( 'index.php', 'post.php', 'edit.php', 'post-new.php', 'edit-tags.php');
	
	if ( in_array( $pagenow, $include_on_pages ) ) {
		$uploads_dir_params = wp_upload_dir();
		$uploads_dir = $uploads_dir_params['basedir'] . '/' . LIVICONS_EVOLUTION_SLUG;
		$uploads_url = $uploads_dir_params['baseurl'] . '/' . LIVICONS_EVOLUTION_SLUG;
		$custom_css_file = $uploads_dir . '/LivIconsEvo.custom.css';
		$custom_js_file = $uploads_dir . '/LivIconsEvo.custom.js';

		wp_enqueue_style( 'livicons-evolution-styles' );
		if ( is_admin() ) {
			wp_enqueue_style(
				'livicons-evolution-dialog-css',
				LIVICONS_EVOLUTION_URL . 'assets/css/LivIconsEvo.dialog.css',
				array( 'livicons-evolution-styles' ),
				LIVICONS_EVOLUTION_VERSION
			);
		}
		if ( is_readable( $custom_css_file ) && filesize( $custom_css_file ) > 0 ) {
			wp_enqueue_style(
				'livicons-evolution-custom-css',
				$uploads_url . '/LivIconsEvo.custom.css',
				array( 'livicons-evolution-styles' ),
				get_option( 'livicons_evolution_dynamic_string', '' )
			);
		}

		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'livicons-evolution-tools' );
		wp_enqueue_script( 'livicons-evolution-defaults' );
		wp_enqueue_script( 'livicons-evolution-core' );
		if ( is_admin() ) {
			wp_enqueue_script(
				'livicons-evolution-dialog-js',
				LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.dialog.js',
				array( 'livicons-evolution-core' ),
				LIVICONS_EVOLUTION_VERSION,
				true
			);
			wp_localize_script( 'livicons-evolution-dialog-js', 'livicons_evolution_confirms_in_dialog',
				array( 
					'reset_options_msg' => esc_html__( 'Are you sure you want to reset these options?', 'livicons-evo' )
				)
			);
		}
		if ( is_readable( $custom_js_file ) && filesize( $custom_js_file ) > 0 ) {
			wp_enqueue_script(
				'livicons-evolution-custom-js',
				$uploads_url . '/LivIconsEvo.custom.js',
				array( 'livicons-evolution-core' ),
				get_option( 'livicons_evolution_dynamic_string', '' ),
				true
			);
		}
	}
}
add_action( 'init', 'livicons_evolution_general_assets' );

// define styles and scripts for setting pages
function livicons_evolution_assets_on_setting_pages( $hook ) {
	global $livicons_evolution_setting_pages;
	if( ! in_array( $hook, $livicons_evolution_setting_pages ) ) {
		return;
	};
	if( $hook === $livicons_evolution_setting_pages[4] ) { // 'CSS & JavaScript' page
		wp_enqueue_code_editor( array( 'type' => 'text/html' ) );
	};
	
	wp_enqueue_style( 'wp-color-picker' );
	wp_enqueue_style( 'livicons-evolution-styles' );
	wp_enqueue_style( 'livicons-evolution-settings-styles', LIVICONS_EVOLUTION_URL . 'assets/css/LivIconsEvo.settings.css', false, LIVICONS_EVOLUTION_VERSION );

	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'wp-color-picker' );
	wp_enqueue_script('livicons-evolution-settings-script', LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.settings.js', array('wp-color-picker'), LIVICONS_EVOLUTION_VERSION, true );
	wp_localize_script( 'livicons-evolution-settings-script', 'livicons_evolution_confirms_in_settings',
		array( 
			'deactivate_code_msg' => esc_html__( 'Are you sure you want to deactivate this code?', 'livicons-evo' ),
			'delete_options_msg' => esc_html__( 'Are you sure you want to delete ALL the options and ALL the custom CSS and JavaScript files upon deleting this plugin?', 'livicons-evo' )
		)
	);
	wp_enqueue_script( 'livicons-evolution-tools' );
	wp_enqueue_script( 'livicons-evolution-defaults' );
	wp_enqueue_script( 'livicons-evolution-core' );
}
add_action( 'admin_enqueue_scripts', 'livicons_evolution_assets_on_setting_pages' );

// Gutenberg editor script
function livicons_evolution_enqueue_assets_gutenberg_editor() {
    wp_enqueue_script( 'livicons-evolution-gutenberg-js' );
}
add_action( 'enqueue_block_editor_assets', 'livicons_evolution_enqueue_assets_gutenberg_editor' );
